/*
 * Druid - a distributed column store.
 * Copyright 2012 - 2015 Metamarkets Group Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.druid.query;

import com.google.common.collect.Ordering;
import com.metamx.common.guava.Sequence;
import com.metamx.common.guava.nary.BinaryFn;
import io.druid.common.guava.CombiningSequence;

import java.util.Map;

/**
 */
public abstract class ResultMergeQueryRunner<T> extends BySegmentSkippingQueryRunner<T>
{
  public ResultMergeQueryRunner(
      QueryRunner<T> baseRunner
  )
  {
    super(baseRunner);
  }

  @Override
  public Sequence<T> doRun(QueryRunner<T> baseRunner, Query<T> query, Map<String, Object> context)
  {
    return CombiningSequence.create(baseRunner.run(query, context), makeOrdering(query), createMergeFn(query));
  }

  protected abstract Ordering<T> makeOrdering(Query<T> query);

  protected abstract BinaryFn<T,T,T> createMergeFn(Query<T> query);
}
