/*
 * Druid - a distributed column store.
 * Copyright 2012 - 2015 Metamarkets Group Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.druid.segment.data;

import com.google.common.collect.Maps;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Map;

/**
*/
class IOPeonForTesting implements IOPeon
{
  Map<String, ByteArrayOutputStream> outStreams = Maps.newHashMap();

  @Override
  public OutputStream makeOutputStream(String filename) throws IOException
  {
    ByteArrayOutputStream stream = outStreams.get(filename);

    if (stream == null) {
      stream = new ByteArrayOutputStream();
      outStreams.put(filename, stream);
    }

    return stream;
  }

  @Override
  public InputStream makeInputStream(String filename) throws IOException
  {
    ByteArrayOutputStream outStream = outStreams.get(filename);

    if (outStream == null) {
      throw new FileNotFoundException(String.format("unknown file[%s]", filename));
    }

    return new ByteArrayInputStream(outStream.toByteArray());
  }

  @Override
  public void cleanup() throws IOException
  {
    outStreams.clear();
  }
}
